pub struct Account {
pub id: String,
pub name: String,
pub settings: Option<Settings>,
pub created_on: Option<DateTime<Utc>>,
}Expand description
Cloudflare Accounts An Account is the root object which owns other resources such as zones, load balancers and billing details. https://api.cloudflare.com/#accounts-properties
Fields
id: StringAccount identifier tag.
name: StringAccount name
settings: Option<Settings>Account Settings
created_on: Option<DateTime<Utc>>describes when the account was created