pub struct AccountDetails {
pub id: String,
pub name: String,
}Expand description
Cloudflare Accounts Details An Account is the root object which owns other resources such as zones, load balancers and billing details. https://api.cloudflare.com/#accounts-properties
Fields
id: StringAccount identifier tag.
name: StringAccount name