pub struct ResponseAndToolCallsResult {
pub response: String,
pub tool_calls: Vec<ToolCall>,
}Expand description
Represents a generated text response and tool calls from the model.
Fields
response: StringThe generated text response.
tool_calls: Vec<ToolCall>Array of tool call requests made during the response generation.