pub struct OptionalParams<'a> {
pub description: Option<&'a str>,
pub ttl: Option<u32>,
pub pop_pools: Option<HashMap<String, Vec<String>>>,
pub region_pools: Option<HashMap<String, Vec<String>>>,
pub proxied: Option<bool>,
pub steering_policy: Option<SteeringPolicy>,
pub session_affinity: Option<SessionAffinity>,
pub session_affinity_attributes: Option<SessionAffinityAttributes>,
pub session_affinity_ttl: Option<u32>,
}Expand description
Optional parameters for creating a Load Balancer.
Fields
description: Option<&'a str>ttl: Option<u32>Time to live (TTL) of the DNS entry for the IP address returned by this load balancer. This only applies to gray-clouded (unproxied) load balancers.
pop_pools: Option<HashMap<String, Vec<String>>>A mapping of Cloudflare PoP identifiers to a list of pool IDs (ordered by their failover priority) for the PoP (datacenter). Any PoPs not explicitly defined will fall back to using default_pools.
region_pools: Option<HashMap<String, Vec<String>>>A mapping of region/country codes to a list of pool IDs (ordered by their failover priority) for the given region. Any regions not explicitly defined will fall back to using default_pools.
proxied: Option<bool>steering_policy: Option<SteeringPolicy>session_affinity: Option<SessionAffinity>session_affinity_attributes: Option<SessionAffinityAttributes>session_affinity_ttl: Option<u32>Trait Implementations
Sourceimpl<'a> Clone for OptionalParams<'a>
impl<'a> Clone for OptionalParams<'a>
Sourcefn clone(&self) -> OptionalParams<'a>
fn clone(&self) -> OptionalParams<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for OptionalParams<'a>
impl<'a> Debug for OptionalParams<'a>
Sourceimpl<'a> Default for OptionalParams<'a>
impl<'a> Default for OptionalParams<'a>
Sourcefn default() -> OptionalParams<'a>
fn default() -> OptionalParams<'a>
Returns the “default value” for a type. Read more