OptionalParams

Struct OptionalParams 

pub struct OptionalParams<'a> {
    pub description: Option<&'a str>,
    pub enabled: Option<bool>,
    pub minimum_origins: Option<u8>,
    pub monitor: Option<&'a str>,
    pub notification_email: Option<&'a str>,
}
Optional parameters for creating a Load Balancer Pool.

Fields

description: Option<&'a str>

A human-readable description of the pool. e.g. “Primary data center - Provider XYZ”

enabled: Option<bool>

Whether to enable (the default) this pool. Disabled pools will not receive traffic and are excluded from health checks. Disabling a pool will cause any load balancers using it to failover to the next pool (if any).

minimum_origins: Option<u8>

The minimum number of origins that must be healthy for this pool to serve traffic. If the number of healthy origins falls below this number, the pool will be marked unhealthy and we will failover to the next available pool.

monitor: Option<&'a str>

The ID of the Monitor to use for health checking origins within this pool.

notification_email: Option<&'a str>

The email address to send health status notifications to. This can be an individual mailbox or a mailing list.