pub struct Params<'a> {
pub name: &'a str,
pub origins: &'a [Origin],
pub optional_params: Option<OptionalParams<'a>>,
}Expand description
Mandatory parameters for creating a Load Balancer Pool.
Fields
name: &'a strA short name (tag) for the pool. Only alphanumeric characters, hyphens and underscores are allowed. E.g. “primary-dc-1”
origins: &'a [Origin]The list of origins within this pool. Traffic directed at this pool is balanced across all currently healthy origins, provided the pool itself is healthy.
optional_params: Option<OptionalParams<'a>>Trait Implementations