pub struct LoadBalancer {Show 16 fields
pub id: String,
pub created_on: DateTime<Utc>,
pub modified_on: DateTime<Utc>,
pub description: String,
pub name: String,
pub enabled: bool,
pub ttl: u32,
pub fallback_pool: String,
pub default_pools: Vec<String>,
pub region_pools: HashMap<String, Vec<String>>,
pub pop_pools: HashMap<String, Vec<String>>,
pub proxied: bool,
pub steering_policy: SteeringPolicy,
pub session_affinity: SessionAffinity,
pub session_affinity_attributes: SessionAffinityAttributes,
pub session_affinity_ttl: u32,
}Fields
id: Stringcreated_on: DateTime<Utc>modified_on: DateTime<Utc>description: Stringname: StringThe DNS hostname to associate with your Load Balancer. If this hostname already exists as a DNS record in Cloudflare’s DNS, the Load Balancer will take precedence and the DNS record will not be used.
enabled: boolttl: u32Time to live (TTL) of the DNS entry for the IP address returned by this load balancer. This only applies to gray-clouded (unproxied) load balancers.
fallback_pool: StringThe pool ID to use when all other pools are detected as unhealthy.
default_pools: Vec<String>A list of pool IDs ordered by their failover priority. Pools defined here are used by default, or when region_pools are not configured for a given region.
region_pools: HashMap<String, Vec<String>>A mapping of region/country codes to a list of pool IDs (ordered by their failover priority) for the given region. Any regions not explicitly defined will fall back to using default_pools.
pop_pools: HashMap<String, Vec<String>>A mapping of Cloudflare PoP identifiers to a list of pool IDs (ordered by their failover priority) for the PoP (datacenter). Any PoPs not explicitly defined will fall back to using default_pools.
proxied: boolsteering_policy: SteeringPolicysession_affinity: SessionAffinitysession_affinity_attributes: SessionAffinityAttributessession_affinity_ttl: u32Trait Implementations
Sourceimpl Clone for LoadBalancer
impl Clone for LoadBalancer
Sourcefn clone(&self) -> LoadBalancer
fn clone(&self) -> LoadBalancer
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more