pub struct CreateNamespace<'a> {
pub account_identifier: &'a str,
pub params: CreateNamespaceParams,
}Expand description
Create a Namespace Creates a namespace under the given title. A 400 is returned if the account already owns a namespace with this title. A namespace must be explicitly deleted to be replaced. https://api.cloudflare.com/#workers-kv-namespace-create-a-namespace
Fields
account_identifier: &'a strparams: CreateNamespaceParamsTrait Implementations
Sourceimpl<'a> Debug for CreateNamespace<'a>
impl<'a> Debug for CreateNamespace<'a>
Sourceimpl<'a> Endpoint<WorkersKvNamespace, (), CreateNamespaceParams> for CreateNamespace<'a>
impl<'a> Endpoint<WorkersKvNamespace, (), CreateNamespaceParams> for CreateNamespace<'a>