pub struct DeleteKey<'a> {
pub account_identifier: &'a str,
pub namespace_identifier: &'a str,
pub key: &'a str,
}Expand description
Delete a key-value pair from Workers KV Deletes a given key from the given namespace in Workers KV. Returns 404 if the given namespace id is not found for an account. https://api.cloudflare.com/#workers-kv-namespace-delete-key-value-pair
Fields
account_identifier: &'a strnamespace_identifier: &'a strkey: &'a strTrait Implementations