pub struct Key {
pub name: String,
pub expiration: Option<DateTime<Utc>>,
pub metadata: Option<Value>,
}Expand description
A name for a value. A value stored under a given key may be retrieved via the same key.
Fields
name: StringA key’s name. The name may be at most 512 bytes. All printable, non-whitespace characters are valid. Use percent-encoding to define key names as part of a URL.
expiration: Option<DateTime<Utc>>The time, measured in number of seconds since the UNIX epoch, at which the key will expire. This property is omitted for keys that will not expire.
metadata: Option<Value>Arbitrary JSON that is associated with a key.