Module framework

Module framework 

This module controls how requests are sent to Cloudflare’s API, and how responses are parsed from it.

Modules

async_api
auth
endpoint
json_utils
mock

Enums

Environment
OrderDirection
SearchMatch
Used as a parameter to API calls that search for a resource (e.g. DNS records). Tells the API whether to return results that match all search requirements or at least one (any).

Traits

ApiResultTraits