[][src]Struct cloudflare::endpoints::workerskv::create_namespace::CreateNamespace

pub struct CreateNamespace<'a> {
    pub account_identifier: &'a str,
    pub params: CreateNamespaceParams,
}

Create a Namespace Creates a namespace under the given title. A 400 is returned if the account already owns a namespace with this title. A namespace must be explicitly deleted to be replaced. https://api.cloudflare.com/#workers-kv-namespace-create-a-namespace

Fields

account_identifier: &'a strparams: CreateNamespaceParams