This module controls how requests are sent to Cloudflare’s API, and how responses are parsed from it.
Modules
Enums
- Environment
- Order
Direction - Search
Match - Used as a parameter to API calls that search for a resource (e.g. DNS records). Tells the API whether to return results that match all search requirements or at least one (any).