cloudflare

Module framework

This module controls how requests are sent to Cloudflare’s API, and how responses are parsed from it.

Modules

async_api
auth
endpoint
response

Structs

HttpApiClientConfig
Configuration for the API client. Allows users to customize its behaviour.

Enums

Environment
Which environment (host path) to use for API calls
Error
Errors encountered while trying to connect to the Cloudflare API
OrderDirection
SearchMatch
Used as a parameter to API calls that search for a resource (e.g. DNS records). Tells the API whether to return results that match all search requirements or at least one (any).