This module controls how requests are sent to Cloudflare’s API, and how responses are parsed from it.
Modules
Structs
- Http
ApiClient Config - Configuration for the API client. Allows users to customize its behaviour.
Enums
- Environment
- Which environment (host path) to use for API calls
- Error
- Errors encountered while trying to connect to the Cloudflare API
- Order
Direction - Search
Match - Used as a parameter to API calls that search for a resource (e.g. DNS records). Tells the API whether to return results that match all search requirements or at least one (any).